@@ -58,6 +58,25 @@ subclasses (:py:class:`AsyncEnvironment`, :py:class:`SyncEnvironment`,
 :py:class:`AsyncPouchDB` and :py:class:`SyncPouchDB`) are the ones
 actually available in the API.
 
+PouchDB Plug-ins
+================
+
+Python-PouchDB not only wraps PouchDB, but also quite a few of its
+plug-ins. The included plug-ins are as follows.
+
+**Third party plug-ins:**
+
+- `PouchDB Spatial <https://github.com/pouchdb/geopouch>`_
+- `GQL <https://github.com/pouchdb/GQL>`_ (`documentation <http://pouchdb.com/gql.html>`_)
+- `PouchDB Search <https://github.com/pouchdb/pouchdb-search>`_
+- `PouchDB Authentication <https://github.com/nolanlawson/pouchdb-authentication>`_
+
+**Plug-ins developed alongside Python-PouchDB:**
+
+- PouchDB Validation
+- PouchDB Show
+- PouchDB List
+
 Unsupported PouchDB APIs
 ========================
 
@@ -74,9 +93,9 @@ to work.
   :py:meth:`AbstractPouchDB.replicate_to` allow you to use at least one
   :py:class:`AbstractPouchDB` object though, so you shouldn't have any
   problems because of this.
-- It's not possible to write a PouchDB plugin in Python. In other words,
-  ``PouchDB.plugin`` isn't implemented. But seriously, why would you
-  ever want to do that anyway?
+- It's not possible to write a PouchDB plug-in in Python. In other
+  words, ``PouchDB.plug-in`` isn't implemented. But seriously, why would
+  you ever want to do that anyway?
 
 It's not impossible to fix this restriction, it's just not something
 that has a very high priority. Patches welcome!
@@ -334,10 +353,10 @@ class AbstractPouchDB(object):
 
 		"""
 
-	#gql plugin
+	#gql plug-in
 	@abc.abstractmethod #pragma: no branch
 	def gql(self, query, **options):
-		"""	Uses the GQL PouchDB plugin. Check out `its documentation
+		"""	Uses the GQL PouchDB plug-in. Check out `its documentation
 		<http://pouchdb.com/gql.html>`_.
 
 		The Google Query Language (GQL) interface provides an
@@ -351,89 +370,151 @@ class AbstractPouchDB(object):
 
 		"""
 
-	#geopouch plugin
+	#geopouch plug-in
 	@abc.abstractmethod #pragma: no branch
 	def spatial(self, fun, **options):
 		"""Same as requesting ``_spatial`` in CouchDB when GeoCouch is
-		installed. Wraps the geopouch plugin.
+		installed. Wraps the geopouch plug-in.
 
 		"""
 
-	#search plugin
+	#search plug-in
 	@abc.abstractmethod #pragma: no branch
 	def search(self, func, **options):
-		"""Wraps the pouchdb-search plugin"""
+		"""Wraps the pouchdb-search plug-in"""
 
-	#validation plugin
+	#authentication plug-in
+	@abc.abstractmethod #pragma: no branch
+	def signup(self, username, password, **options):
+		"""Sign up a new user who doesn't exist yet. Throws an error if
+		the user already exists or if the username is invalid, or if
+		some network error occurred. CouchDB has some limitations on
+		user names (e.g. they cannot contain the character :).
+
+		Note: Signing up does not automatically log in a user; you will
+		need to call db.login() afterwards.
+		
+		Options:
+		- metadata : Object of metadata you want to store with the username, e.g. an email address or any other info. Can be as deeply structured as you want.
+
+		"""
+
+	def signUp(self, *args, **kwargs):
+		"""Alias for :meth:`signup`."""
+
+		return self.signup(*args, **kwargs)
+
+	@abc.abstractmethod #pragma: no branch
+	def login(self, username, password, **options):
+		"""Log in an existing user. Throws an error if the user doesn't
+		exist yet, the password is wrong, the HTTP server is
+		unreachable, or a meteor struck your computer.
+
+		"""
+
+	def logIn(self, *args, **kwargs):
+		"""Alias for :meth:`login`."""
+
+		return self.login(*args, **kwargs)
+
+	@abc.abstractmethod #pragma: no branch
+	def logout(self, **options):
+		"""Logs out whichever user is currently logged in. If nobody's
+		logged in, it does nothing and just returns {"ok": True}.
+
+		"""
+
+	def logOut(self, *args, **kwargs):
+		"""Alias for :meth:`logOut`."""
+
+		return self.logout(*args, **kwargs)
+
+	@abc.abstractmethod #pragma: no branch
+	def getSession(self, **options):
+		"""Returns information about the current session. In other
+		words, this tells you which user is currently logged in.
+
+		"""
+
+	@abc.abstractmethod #pragma: no branch
+	def getUser(self, username, **options):
+		"""Returns the user document associated with a username.
+		(CouchDB, in a pleasing show of consistency, stores users as
+		JSON documents in the special _users database.) This is the
+		primary way to get metadata about a user.
+
+		"""
+
+	#validation plug-in
 	@abc.abstractmethod #pragma: no branch
 	def validatingPut(self, doc, id=None, rev=None, **options):
 		"""Same as :py:meth:`put`, but validates like in CouchDB. Wraps
-		the validation PouchDB plugin.
+		the validation PouchDB plug-in.
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def validatingPost(self, doc, **options):
 		"""Same as :py:meth:`post`, but validates like in CouchDB. Wraps
-		the validation PouchDB plugin.
+		the validation PouchDB plug-in.
 
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def validatingRemove(self, doc, **options):
 		"""Same as :py:meth:`remove`, but validates like in CouchDB.
-		Wraps the validation PouchDB plugin.
+		Wraps the validation PouchDB plug-in.
 
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def validatingBulkDocs(self, docs, **options):
 		"""Same as :py:meth:`bulkDocs`, but validates like in CouchDB.
-		Wraps the validation PouchDB plugin.
+		Wraps the validation PouchDB plug-in.
 
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def validatingPutAttachment(self, docId, attachmentId, doc, type, rev=None, **options):
 		"""Same as :py:meth:`putAttachment`, but validates like in
-		CouchDB. Wraps the validation PouchDB plugin.
+		CouchDB. Wraps the validation PouchDB plug-in.
 
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def validatingRemoveAttachment(self, docId, attachmentId, rev, **options):
 		"""Same as :py:meth:`removeAttachment`, but validates like in
-		CouchDB. Wraps the validation PouchDB plugin.
+		CouchDB. Wraps the validation PouchDB plug-in.
 
 		"""
 
-	#show plugin - experimental so private for now
+	#show plug-in - experimental so private for now
 	@abc.abstractmethod #pragma: no branch
 	def show(self, showPath, **options):
 		"""Same as requesting ``_show`` in CouchDB. Wraps the show
-		PouchDB plugin.
+		PouchDB plug-in.
 
 		"""
 
-	#list plugin - experimental so private for now
+	#list plug-in - experimental so private for now
 	@abc.abstractmethod #pragma: no branch
 	def list(self, listPath, **options):
 		"""Same as requesting ``_list`` in CouchDB. Wraps the list
-		PouchDB plugin.
+		PouchDB plug-in.
 
 		"""
 
-	#update plugin - experimental so private for now
+	#update plug-in - experimental so private for now
 	@abc.abstractmethod #pragma: no branch
 	def _updatingPut(self, query, **options):
 		"""Same as sending a PUT to ``_update`` in CouchDB. Wraps the
-		update PouchDB plugin.
+		update PouchDB plug-in.
 
 		"""
 
 	@abc.abstractmethod #pragma: no branch
 	def _updatingPost(self, query, **options):
 		"""Same as sending a POST to ``_update`` in CouchDB. Wraps the
-		update PouchDB plugin.
+		update PouchDB plug-in.
 
 		"""
 
@@ -517,21 +598,37 @@ class SyncPouchDB(AbstractPouchDB):
 	def revsDiff(self, diff):
 		return self._syncCall("revsDiff", diff)
 
-	#gql plugin
+	#gql plug-in
 	def gql(self, query, **options):
 		with _getting_callback_result(self._ctx) as info:
 			self._ctx.call(self._id, "gql", query, options, info["callback"])
 		return info["resp"]
 
-	#spatial plugin
+	#spatial plug-in
 	def spatial(self, fun, **options):
 		return self._syncCall("spatial", fun, options)
 
-	#search plugin
+	#search plug-in
 	def search(self, func, **options):
 		return self._syncCall("search", func, options)
 
-	#validation plugin
+	#authentication plug-in
+	def signup(self, username, password, **options):
+		return self._syncCall("signup", username, password, options)
+
+	def login(self, username, password, **options):
+		return self._syncCall("login", username, password, options)
+
+	def logout(self, **options):
+		return self._syncCall("logout", options)
+
+	def getSession(self, **options):
+		return self._syncCall("getSession", options)
+
+	def getUser(self, username, **options):
+		return self._syncCall("getUser", username, options)
+
+	#validation plug-in
 	def validatingPut(self, doc, id=None, rev=None, **options):
 		return self._syncCall("validatingPut", doc, id, rev, options)
 
@@ -550,15 +647,15 @@ class SyncPouchDB(AbstractPouchDB):
 	def validatingRemoveAttachment(self, docId, attachmentId, rev, **options):
 		return self._syncCall("validatingRemoveAttachment", docId, attachmentId, rev, options)
 
-	#show plugin
+	#show plug-in
 	def show(self, showPath, **options):
 		return self._syncCall("show", showPath, options)
 
-	#list plugin
+	#list plug-in
 	def list(self, listPath, **options):
 		return self._syncCall("list", listPath, options)
 
-	#update plugin
+	#update plug-in
 	def _updatingPut(self, query, **options):
 		return self._syncCall("updatingPut", query, options)
 
@@ -671,18 +768,34 @@ class AsyncPouchDB(AbstractPouchDB):
 	def revsDiff(self, diff, callback=None):
 		return self._asyncCall("revsDiff", diff, callback)
 
-	#gql plugin
+	#gql plug-in
 	def gql(self, query, callback=None, **options):
 		return self._asyncCall("gql", query, options, callback)
 
-	#spatial plugin
+	#spatial plug-in
 	def spatial(self, fun, callback=None, **options):
 		return self._asyncCall("spatial", fun, options, callback)
 
-	#search plugin
+	#search plug-in
 	def search(self, func, callback=None, **options):
 		return self._asyncCall("search", func, options, callback)
 
+	#authentication plug-in
+	def signup(self, username, password, callback=None, **options):
+		return self._asyncCall("signup", username, password, options, callback)
+
+	def login(self, username, password, callback=None, **options):
+		return self._asyncCall("login", username, password, options, callback)
+
+	def logout(self, callback=None, **options):
+		return self._asyncCall("logout", options, callback)
+
+	def getSession(self, callback=None, **options):
+		return self._asyncCall("getSession", options, callback)
+
+	def getUser(self, username, callback=None, **options):
+		return self._asyncCall("getUser", username, options, callback)
+
 	#validation functions
 	def validatingPut(self, doc, id=None, rev=None, callback=None, **options):
 		return self._asyncCall("validatingPut", *self._handlePutArgs(doc, id, rev, callback, options))
@@ -702,15 +815,15 @@ class AsyncPouchDB(AbstractPouchDB):
 	def validatingRemoveAttachment(self, docId, attachmentId, rev, callback=None, **options):
 		return self._asyncCall("validatingRemoveAttachment", docId, attachmentId, rev, options, callback)
 
-	#show plugin
+	#show plug-in
 	def show(self, showPath, callback=None, **options):
 		return self._asyncCall("show", showPath, options, callback)
 
-	#list plugin
+	#list plug-in
 	def list(self, listPath, callback=None, **options):
 		return self._asyncCall("list", listPath, options, callback)
 
-	#update plugin
+	#update plug-in
 	def _updatingPut(self, query, callback=None, **options):
 		return self._asyncCall("updatingPut", query, options, callback)
 
