@@ -128,6 +128,10 @@ class JSContext(object):
 		#before said promise is accessable to a Python user.
 		self._evalJsWaiting = True
 
+		#this is used to track functions that are being waited on via
+		#waitUntilCalled.
+		self._waitedOn = set()
+
 		self._app = QtGui.QApplication.instance()
 		if not self._app: #pragma: no branch
 			self._app = QtGui.QApplication(sys.argv)
@@ -205,7 +209,7 @@ class JSContext(object):
 
 		def callFunc():
 			logger.debug("callback '%s' called with args %s", id, args)
-			func._called = True
+			self._waitedOn.discard(func)
 			func(*self._toPyArgs(args))
 
 		func = self._functions[unicode(id)]
@@ -310,11 +314,10 @@ class JSContext(object):
 		#when only one, put it in a list.
 		if callable(callbacks):
 			callbacks = [callbacks]
-		#fix for callbacks that have been callbacks before.
-		for callback in callbacks:
-			callback._called = False
 
-		while not any(getattr(callback, "_called", False) for callback in callbacks):
+		self._waitedOn.update(callbacks)
+
+		while all(callback in self._waitedOn for callback in callbacks):
 			self._app.processEvents()
 
 			errors = []
@@ -327,6 +330,10 @@ class JSContext(object):
 			if errors:
 				raise JSError(errors)
 
+		for callback in callbacks:
+			#to clean the set if called with multiple callbacks
+			self._waitedOn.discard(callback)
+
 	def _evalJs(self, userJs):
 		logger.debug("evalling JS: %s", userJs.strip())
 		returned = {}
